@@ -74,12 +74,10 @@ from guidata.utils import update_dataset
 from guiqwt.config import CONF, _
 from guiqwt.styles import LabelParam, AnnotationParam
 from guiqwt.shapes import (AbstractShape, RectangleShape, EllipseShape,
-                           SegmentShape, PointShape, VerticalCursor,
-                           HorizontalCursor, ObliqueRectangleShape)
+                           SegmentShape, PointShape, ObliqueRectangleShape)
 from guiqwt.label import DataInfoLabel
 from guiqwt.interfaces import IShapeItemType, ISerializableType
-from guiqwt.signals import (SIG_ANNOTATION_CHANGED, SIG_ITEM_MOVED,
-                            SIG_CURSOR_MOVED)
+from guiqwt.signals import SIG_ANNOTATION_CHANGED, SIG_ITEM_MOVED
 from guiqwt.geometry import (compute_center, compute_rect_size,
                              compute_distance, compute_angle)
 
@@ -213,20 +211,24 @@ class AnnotatedShape(AbstractShape):
                 
     def get_center(self):
         """Return shape center coordinates: (xc, yc)"""
+        return self.shape.get_center()
+        
+    def get_tr_center(self):
+        """Return shape center coordinates after applying transform matrix"""
         raise NotImplementedError
         
-    def get_center_str(self):
+    def get_tr_center_str(self):
         """Return center coordinates as a string (with units)"""
-        xc, yc = self.get_center()
+        xc, yc = self.get_tr_center()
         return "( %s ; %s )" % (self.x_to_str(xc, 1), self.y_to_str(yc, 1))
         
-    def get_size(self):
-        """Return shape size: (width, height)"""
+    def get_tr_size(self):
+        """Return shape size after applying transform matrix"""
         raise NotImplementedError
         
-    def get_size_str(self):
+    def get_tr_size_str(self):
         """Return size as a string (with units)"""
-        xs, ys = self.get_size()
+        xs, ys = self.get_tr_size()
         return "%s x %s" % (self.x_to_str(xs, 2), self.y_to_str(ys, 2))
         
     def get_infos(self):
@@ -282,12 +284,12 @@ class AnnotatedShape(AbstractShape):
 
     def select(self):
         """Select item"""
-        super(AnnotatedShape, self).select()
+        AbstractShape.select(self)
         self.shape.select()
     
     def unselect(self):
         """Unselect item"""
-        super(AnnotatedShape, self).unselect()
+        AbstractShape.unselect(self)
         self.shape.unselect()
 
     def get_item_parameters(self, itemparams):
@@ -335,7 +337,7 @@ class AnnotatedPoint(AnnotatedShape):
     def set_label_position(self):
         """Set label position, for instance based on shape position"""
         x, y = self.shape.points[0]
-        self.label.set_position(x, y)
+        self.label.set_pos(x, y)
         
     #----AnnotatedShape API-----------------------------------------------------
     def get_infos(self):
@@ -371,20 +373,20 @@ class AnnotatedSegment(AnnotatedShape):
         """
         return self.shape.get_rect()
         
-    def get_length(self):
-        """Return segment length"""
-        return compute_distance(*self.get_transformed_coords(0, 2))
+    def get_tr_length(self):
+        """Return segment length after applying transform matrix"""
+        return compute_distance(*self.get_transformed_coords(0, 1))
     
     #----AnnotatedShape API-----------------------------------------------------
     def set_label_position(self):
         """Set label position, for instance based on shape position"""
         x1, y1, x2, y2 = self.get_rect()
-        self.label.set_position(*compute_center(x1, y1, x2, y2))
+        self.label.set_pos(*compute_center(x1, y1, x2, y2))
         
     #----AnnotatedShape API-----------------------------------------------------
     def get_infos(self):
         """Return formatted string with informations on current shape"""
-        return _("Distance:") + " " + self.x_to_str(self.get_length(), 2)
+        return _("Distance:") + " " + self.x_to_str(self.get_tr_length(), 2)
 
 
 class AnnotatedRectangle(AnnotatedShape):
@@ -418,26 +420,26 @@ class AnnotatedRectangle(AnnotatedShape):
     def set_label_position(self):
         """Set label position, for instance based on shape position"""
         x_label, y_label = self.shape.points.min(axis=0)
-        self.label.set_position(x_label, y_label)
+        self.label.set_pos(x_label, y_label)
     
     def get_computations_text(self):
         """Return formatted string with informations on current shape"""
         tdict = self.get_string_dict()
         return u"%(center_n)s ( %(center)s )<br>%(size_n)s %(size)s" % tdict
         
-    def get_center(self):
-        """Return center coordinates: (xc, yc)"""
+    def get_tr_center(self):
+        """Return shape center coordinates after applying transform matrix"""
         return compute_center(*self.get_transformed_coords(0, 2))
         
-    def get_size(self):
-        """Return rectangle size: (width, height)"""
+    def get_tr_size(self):
+        """Return shape size after applying transform matrix"""
         return compute_rect_size(*self.get_transformed_coords(0, 2))
         
     def get_infos(self):
         """Return formatted string with informations on current shape"""
         return "<br>".join([
-                            _("Center:") + " " + self.get_center_str(),
-                            _("Size:") + " " + self.get_size_str(),
+                            _("Center:") + " " + self.get_tr_center_str(),
+                            _("Size:") + " " + self.get_tr_size_str(),
                             ])
 
 
@@ -455,8 +457,9 @@ class AnnotatedObliqueRectangle(AnnotatedRectangle):
         self.set_rect(x0, y0, x1, y1, x2, y2, x3, y3)
         
     #----Public API-------------------------------------------------------------
-    def get_angle(self):
-        """Return X-diameter angle with horizontal direction"""
+    def get_tr_angle(self):
+        """Return X-diameter angle with horizontal direction,
+        after applying transform matrix"""
         xcoords = self.get_transformed_coords(0, 1)
         _x, yr1 = self.apply_transform_matrix(1., 1.)
         _x, yr2 = self.apply_transform_matrix(1., 2.)
@@ -475,7 +478,7 @@ class AnnotatedObliqueRectangle(AnnotatedRectangle):
     #----AnnotatedShape API-----------------------------------------------------
     def set_label_position(self):
         """Set label position, for instance based on shape position"""
-        self.label.set_position(*self.get_center())
+        self.label.set_pos(*self.get_center())
         
     #----RectangleShape API-----------------------------------------------------
     def set_rect(self, x0, y0, x1, y1, x2, y2, x3, y3):
@@ -499,8 +502,8 @@ class AnnotatedObliqueRectangle(AnnotatedRectangle):
         self.shape.set_rect(x0, y0, x1, y1, x2, y2, x3, y3)
         self.set_label_position()
         
-    def get_size(self):
-        """Return rectangle size: (width, height)"""
+    def get_tr_size(self):
+        """Return shape size after applying transform matrix"""
         dx = compute_distance(*self.get_transformed_coords(0, 1))
         dy = compute_distance(*self.get_transformed_coords(0, 3))
         return dx, dy
@@ -509,9 +512,9 @@ class AnnotatedObliqueRectangle(AnnotatedRectangle):
     def get_infos(self):
         """Return formatted string with informations on current shape"""
         return "<br>".join([
-                            _("Center:") + " " + self.get_center_str(),
-                            _("Size:") + " " + self.get_size_str(),
-                            _(u"Angle:") + u" %.1f°" % self.get_angle(),
+                            _("Center:") + " " + self.get_tr_center_str(),
+                            _("Size:") + " " + self.get_tr_size_str(),
+                            _(u"Angle:") + u" %.1f°" % self.get_tr_angle(),
                             ])
     
 
@@ -531,21 +534,25 @@ class AnnotatedEllipse(AnnotatedShape):
 
     #----Public API-------------------------------------------------------------
     def set_xdiameter(self, x0, y0, x1, y1):
-        """Set the coordinates of the ellipse's X-axis diameter"""
+        """Set the coordinates of the ellipse's X-axis diameter
+        Warning: transform matrix is not applied here"""
         self.shape.set_xdiameter(x0, y0, x1, y1)
         self.set_label_position()
                          
     def get_xdiameter(self):
-        """Return the coordinates of the ellipse's X-axis diameter"""
+        """Return the coordinates of the ellipse's X-axis diameter
+        Warning: transform matrix is not applied here"""
         return self.shape.get_xdiameter()
                          
     def set_ydiameter(self, x2, y2, x3, y3):
-        """Set the coordinates of the ellipse's Y-axis diameter"""
+        """Set the coordinates of the ellipse's Y-axis diameter
+        Warning: transform matrix is not applied here"""
         self.shape.set_ydiameter(x2, y2, x3, y3)
         self.set_label_position()
                          
     def get_ydiameter(self):
-        """Return the coordinates of the ellipse's Y-axis diameter"""
+        """Return the coordinates of the ellipse's Y-axis diameter
+        Warning: transform matrix is not applied here"""
         return self.shape.get_ydiameter()
 
     def get_rect(self):
@@ -554,8 +561,9 @@ class AnnotatedEllipse(AnnotatedShape):
     def set_rect(self, x0, y0, x1, y1):
         raise NotImplementedError
         
-    def get_angle(self):
-        """Return X-diameter angle with horizontal direction"""
+    def get_tr_angle(self):
+        """Return X-diameter angle with horizontal direction,
+        after applying transform matrix"""
         xcoords = self.get_transformed_coords(0, 1)
         _x, yr1 = self.apply_transform_matrix(1., 1.)
         _x, yr2 = self.apply_transform_matrix(1., 2.)
@@ -570,28 +578,28 @@ class AnnotatedEllipse(AnnotatedShape):
     def set_label_position(self):
         """Set label position, for instance based on shape position"""
         x_label, y_label = self.shape.points.mean(axis=0)
-        self.label.set_position(x_label, y_label)
+        self.label.set_pos(x_label, y_label)
         
-    def get_center(self):
+    def get_tr_center(self):
         """Return center coordinates: (xc, yc)"""
         return compute_center(*self.get_transformed_coords(0, 1))
         
-    def get_size(self):
-        """Return ellipse size: (width, height)"""
+    def get_tr_size(self):
+        """Return shape size after applying transform matrix"""
         xcoords = self.get_transformed_coords(0, 1)
         ycoords = self.get_transformed_coords(2, 3)
         dx = compute_distance(*xcoords)
         dy = compute_distance(*ycoords)
-        if np.fabs(self.get_angle()) > 45:
+        if np.fabs(self.get_tr_angle()) > 45:
             dx, dy = dy, dx
         return dx, dy
         
     def get_infos(self):
         """Return formatted string with informations on current shape"""
         return "<br>".join([
-                            _("Center:") + " " + self.get_center_str(),
-                            _("Size:") + " " + self.get_size_str(),
-                            _(u"Angle:") + u" %.1f°" % self.get_angle(),
+                            _("Center:") + " " + self.get_tr_center_str(),
+                            _("Size:") + " " + self.get_tr_size_str(),
+                            _(u"Angle:") + u" %.1f°" % self.get_tr_angle(),
                             ])
         
 
@@ -604,127 +612,18 @@ class AnnotatedCircle(AnnotatedEllipse):
     def __init__(self, x1=0, y1=0, x2=0, y2=0, annotationparam=None):
         AnnotatedEllipse.__init__(self, x1, y1, x2, y2, 1., annotationparam)
         
-    def get_diameter(self):
-        """Return circle diameter"""
+    def get_tr_diameter(self):
+        """Return circle diameter after applying transform matrix"""
         return compute_distance(*self.get_transformed_coords(0, 1))
         
     #----AnnotatedShape API-------------------------------------------------
     def get_infos(self):
         """Return formatted string with informations on current shape"""
         return "<br>".join([
-                    _("Center:")+" "+self.get_center_str(),
-                    _("Diameter:")+" "+self.x_to_str(self.get_diameter(), 2),
+                    _("Center:")+" "+self.get_tr_center_str(),
+                    _("Diameter:")+" "+self.x_to_str(self.get_tr_diameter(), 2),
                             ])
 
     #----AnnotatedEllipse API---------------------------------------------------
     def set_rect(self, x0, y0, x1, y1):
         self.shape.set_rect(x0, y0, x1, y1)
-        
-
-
-class AnnotatedCursor(AnnotatedShape):
-    """
-    Construct an annotated vertical cursor in x=pos
-    with properties set with *annotationparam* 
-    (see :py:class:`guiqwt.styles.AnnotationParam`)
-    """
-    LABEL_ANCHOR = "BL"
-
-    def __init__(self, pos=0, annotationparam=None, moveable=True):
-        self._can_move = moveable
-        self._can_resize = moveable
-        
-        AnnotatedShape.__init__(self, annotationparam)
-        self.set_pos(pos)
-        
-    #----IBasePlotItem API------------------------------------------------------
-    def select(self):
-        """Select item"""
-        AnnotatedShape.select(self)
-        param = self.label.labelparam
-        param.color = self.shape.shapeparam.sel_line.color
-        param.update_label(self.label)
-        
-    def unselect(self):
-        """Unselect item"""
-        AnnotatedShape.unselect(self)
-        param = self.label.labelparam
-        param.color = self.shape.shapeparam.line.color
-        param.update_label(self.label)
-        
-    #----AnnotatedShape API-----------------------------------------------------
-    def set_pos(self, pos):
-        self.shape.set_pos(pos, dosignal=False)
-
-    def get_pos(self):
-        return self.shape.get_pos()
-        
-    def set_style(self, section, option):
-        pass
-           
-    def hit_test(self, pos):
-        return self.shape.hit_test(pos)
-        
-    def move_point_to(self, handle, pos, ctrl=None):
-        super(AnnotatedCursor, self).move_point_to(handle, pos, ctrl)
-        if self.plot():
-            self.plot().emit(SIG_CURSOR_MOVED, self, self.get_pos())
-        
-    def draw(self, painter, xMap, yMap, canvasRect):
-        self.set_label_position()
-        super(AnnotatedCursor, self).draw(painter, xMap, yMap, canvasRect)
-        
-    def create_label(self):
-        """Return the label object associated to this annotated shape object"""
-        label_param = LabelParam(_("Label"), icon='label.png')
-        label_param.read_config(CONF, "plot", "shape/cursor_label")
-        label_param.anchor = self.LABEL_ANCHOR
-        label_param.color = self.shape.shapeparam.line.color
-        return DataInfoLabel(label_param, [self])
-        
-    #----AnnotatedShape API-----------------------------------------------------
-    def create_shape(self):
-        """Return the shape object associated to this annotated shape object"""
-        return self.SHAPE_CLASS(0, self.can_move())
-        
-    def get_infos(self):
-        """Return dictionary with measured data on shape"""
-        raise NotImplementedError
-        
-        
-class AnnotatedVCursor(AnnotatedCursor):
-    SHAPE_CLASS = VerticalCursor
-    def move_local_point_to(self, handle, pos, ctrl=None):
-        val = self.plot().invTransform(self.xAxis(), pos.x())
-        self.move_point_to(handle, (val, 0))
-        
-    def set_label_position(self):
-        """Set label position, for instance based on shape position"""
-        plot = self.plot()
-        y = plot.invTransform(self.yAxis(),
-                              plot.canvas().contentsRect().bottomLeft().y())
-        self.label.set_position(self.shape.pos, y)
-        
-    #----AnnotatedShape API-----------------------------------------------------
-    def get_infos(self):
-        """Return dictionary with measured data on shape"""
-        return self.x_to_str(self.get_pos(), 1)
-        
-
-class AnnotatedHCursor(AnnotatedCursor):
-    SHAPE_CLASS = HorizontalCursor
-    def move_local_point_to(self, handle, pos, ctrl=None):
-        val = self.plot().invTransform(self.yAxis(), pos.y())
-        self.move_point_to(handle, (val, 0))
-        
-    def set_label_position(self):
-        """Set label position, for instance based on shape position"""
-        plot = self.plot()
-        x = plot.invTransform(self.xAxis(),
-                              plot.canvas().contentsRect().bottomLeft().x())
-        self.label.set_position(x, self.shape.pos)
-        
-    #----AnnotatedShape API-----------------------------------------------------
-    def get_infos(self):
-        """Return dictionary with measured data on shape"""
-        return self.y_to_str(self.get_pos(), 1)
