@@ -36,8 +36,6 @@ DEFAULTS = {
               
               "title/font/size" : 14,
               "title/font/bold" : False,
-              "label/font/size" : 12,
-              "label/font/bold" : False,
 
               "selected_curve_symbol/marker" : 'Rect',
               "selected_curve_symbol/edgecolor" : "gray",
@@ -107,10 +105,25 @@ DEFAULTS = {
               "marker/curve/text/textcolor" : "black",
               "marker/curve/text/background_color" : "#ffffff",
               "marker/curve/text/background_alpha" : 0.8,
-              "marker/curve/pen/style" : "SolidLine",
-              "marker/curve/pen/color" : "black",
-              "marker/curve/pen/width" : 0,
-              "marker/curve/linestyle" : 0,
+              "marker/curve/line/style" : "SolidLine",
+              "marker/curve/line/color" : "black",
+              "marker/curve/line/width" : 0,
+              "marker/curve/sel_symbol/marker" : 'Rect',
+              "marker/curve/sel_symbol/edgecolor" : "blue",
+              "marker/curve/sel_symbol/facecolor" : "cyan",
+              "marker/curve/sel_symbol/alpha" : .8,
+              "marker/curve/sel_symbol/size" : 7,
+              "marker/curve/sel_text/font/size" : 8,
+              "marker/curve/sel_text/font/family" : "default",
+              "marker/curve/sel_text/font/bold" : False,
+              "marker/curve/sel_text/font/italic" : False,
+              "marker/curve/sel_text/textcolor" : "black",
+              "marker/curve/sel_text/background_color" : "#ffffff",
+              "marker/curve/sel_text/background_alpha" : 0.8,
+              "marker/curve/sel_line/style" : "SolidLine",
+              "marker/curve/sel_line/color" : "black",
+              "marker/curve/sel_line/width" : 0,
+              "marker/curve/markerstyle" : "NoLine",
               "marker/curve/spacing" : 7,
 
               "marker/cross/symbol/marker" : 'Cross',
@@ -125,10 +138,25 @@ DEFAULTS = {
               "marker/cross/text/textcolor" : "black",
               "marker/cross/text/background_color" : "#ffffff",
               "marker/cross/text/background_alpha" : 0.8,
-              "marker/cross/pen/style" : "DashLine",
-              "marker/cross/pen/color" : "yellow",
-              "marker/cross/pen/width" : 1,
-              "marker/cross/linestyle" : 3,
+              "marker/cross/line/style" : "DashLine",
+              "marker/cross/line/color" : "yellow",
+              "marker/cross/line/width" : 1,
+              "marker/cross/sel_symbol/marker" : 'Cross',
+              "marker/cross/sel_symbol/edgecolor" : "black",
+              "marker/cross/sel_symbol/facecolor" : "red",
+              "marker/cross/sel_symbol/alpha" : 1.,
+              "marker/cross/sel_symbol/size" : 8,
+              "marker/cross/sel_text/font/family" : "default",
+              "marker/cross/sel_text/font/size" : 8,
+              "marker/cross/sel_text/font/bold" : False,
+              "marker/cross/sel_text/font/italic" : False,
+              "marker/cross/sel_text/textcolor" : "black",
+              "marker/cross/sel_text/background_color" : "#ffffff",
+              "marker/cross/sel_text/background_alpha" : 0.8,
+              "marker/cross/sel_line/style" : "DashLine",
+              "marker/cross/sel_line/color" : "yellow",
+              "marker/cross/sel_line/width" : 1,
+              "marker/cross/markerstyle" : "Cross",
               "marker/cross/spacing" : 7,
 
               "marker/selectpoint/symbol/marker" : 'Rect',
@@ -143,12 +171,60 @@ DEFAULTS = {
               "marker/selectpoint/text/textcolor" : "black",
               "marker/selectpoint/text/background_color" : "#ffffff",
               "marker/selectpoint/text/background_alpha" : 0.8,
-              "marker/selectpoint/pen/style" : "SolidLine",
-              "marker/selectpoint/pen/color" : "black",
-              "marker/selectpoint/pen/width" : 0,
-              "marker/selectpoint/linestyle" : 0,
+              "marker/selectpoint/line/style" : "SolidLine",
+              "marker/selectpoint/line/color" : "black",
+              "marker/selectpoint/line/width" : 0,
+              "marker/selectpoint/sel_symbol/marker" : 'Rect',
+              "marker/selectpoint/sel_symbol/edgecolor" : "blue",
+              "marker/selectpoint/sel_symbol/facecolor" : "cyan",
+              "marker/selectpoint/sel_symbol/alpha" : .8,
+              "marker/selectpoint/sel_symbol/size" : 7,
+              "marker/selectpoint/sel_text/font/size" : 8,
+              "marker/selectpoint/sel_text/font/family" : "default",
+              "marker/selectpoint/sel_text/font/bold" : False,
+              "marker/selectpoint/sel_text/font/italic" : False,
+              "marker/selectpoint/sel_text/textcolor" : "black",
+              "marker/selectpoint/sel_text/background_color" : "#ffffff",
+              "marker/selectpoint/sel_text/background_alpha" : 0.8,
+              "marker/selectpoint/sel_line/style" : "SolidLine",
+              "marker/selectpoint/sel_line/color" : "black",
+              "marker/selectpoint/sel_line/width" : 0,
+              "marker/selectpoint/markerstyle" : "NoLine",
               "marker/selectpoint/spacing" : 7,
 
+              "marker/cursor/line/style" : "SolidLine",
+              "marker/cursor/line/color" : "#ff9393",
+              "marker/cursor/line/width" : 1.,
+              "marker/cursor/symbol/marker" : 'Ellipse',
+              "marker/cursor/symbol/size" : 7,
+              "marker/cursor/symbol/edgecolor" : "white",
+              "marker/cursor/symbol/facecolor" : "#ff9393",
+              "marker/cursor/symbol/alpha" : 1.,
+              "marker/cursor/text/font/size" : 8,
+              "marker/cursor/text/font/family" : "default",
+              "marker/cursor/text/font/bold" : False,
+              "marker/cursor/text/font/italic" : False,
+              "marker/cursor/text/textcolor" : "#ff9393",
+              "marker/cursor/text/background_color" : "#ffffff",
+              "marker/cursor/text/background_alpha" : 0.8,
+              "marker/cursor/sel_line/style" : "SolidLine",
+              "marker/cursor/sel_line/color" : "red",
+              "marker/cursor/sel_line/width" : 2.,
+              "marker/cursor/sel_symbol/marker" : 'Ellipse',
+              "marker/cursor/sel_symbol/size" : 9,
+              "marker/cursor/sel_symbol/edgecolor" : "white",
+              "marker/cursor/sel_symbol/facecolor" : "red",
+              "marker/cursor/sel_symbol/alpha" : .9,
+              "marker/cursor/sel_text/font/size" : 8,
+              "marker/cursor/sel_text/font/family" : "default",
+              "marker/cursor/sel_text/font/bold" : True,
+              "marker/cursor/sel_text/font/italic" : False,
+              "marker/cursor/sel_text/textcolor" : "red",
+              "marker/cursor/sel_text/background_color" : "#ffffff",
+              "marker/cursor/sel_text/background_alpha" : 0.8,
+              "marker/cursor/markerstyle" : "NoLine",
+              "marker/cursor/spacing" : 7,
+
               "shape/drag/line/style" : 'SolidLine',
               "shape/drag/line/color" : "#ffff00",
               "shape/drag/line/width" : 1,
@@ -430,23 +506,6 @@ DEFAULTS = {
               "shape/label/abspos" : False,
               "shape/label/move_anchor" : True,
               
-              "shape/cursor_label/symbol/marker" : "NoSymbol",
-              "shape/cursor_label/symbol/size" : 0,
-              "shape/cursor_label/symbol/edgecolor" : "white",
-              "shape/cursor_label/symbol/facecolor" : "white",
-              "shape/cursor_label/border/style" : "SolidLine",
-              "shape/cursor_label/border/color" : "#cbcbcb",
-              "shape/cursor_label/border/width" : 0,
-              "shape/cursor_label/font/size" : 8,
-              "shape/cursor_label/font/family": "default",
-              "shape/cursor_label/font/bold" : False,
-              "shape/cursor_label/font/italic" : False,
-              "shape/cursor_label/color" : "black",
-              "shape/cursor_label/bgcolor" : "white",
-              "shape/cursor_label/bgalpha" : 0.8,
-              "shape/cursor_label/abspos" : False,
-              "shape/cursor_label/move_anchor" : True,
-
               "label/symbol/marker" : "NoSymbol",
               "label/symbol/size" : 0,
               "label/symbol/edgecolor" : "white",
@@ -464,7 +523,7 @@ DEFAULTS = {
               "label/anchor" : "TL",
               "label/xc" : 0,
               "label/yc" : 0,
-              "label/abspos" : True,
+              "label/abspos" : False,
               "label/absg" : "TR",
               "label/xg" : 0.0,
               "label/yg" : 0.0,
@@ -582,7 +641,7 @@ DEFAULTS = {
               "marker/curve/symbol/facecolor" : "blue",
               "marker/curve/symbol/alpha" : .8,
               "marker/curve/symbol/size" : 8,
-              "marker/curve/text/font/size" : 11,
+              "marker/curve/text/font/size" : 8,
               "marker/curve/text/font/family" : "default",
               "marker/curve/text/font/bold" : False,
               "marker/curve/text/font/italic" : False,
@@ -592,7 +651,7 @@ DEFAULTS = {
               "marker/curve/pen/style" : "SolidLine",
               "marker/curve/pen/color" : "black",
               "marker/curve/pen/width" : 0,
-              "marker/curve/linestyle" : 0,
+              "marker/curve/markerstyle" : "NoLine",
 
               "marker/cross/symbol/marker" : 'Cross',
               "marker/cross/symbol/edgecolor" : "black",
@@ -600,7 +659,7 @@ DEFAULTS = {
               "marker/cross/symbol/alpha" : 1.,
               "marker/cross/symbol/size" : 8,
               "marker/cross/text/font/family" : "default",
-              "marker/cross/text/font/size" : 11,
+              "marker/cross/text/font/size" : 8,
               "marker/cross/text/font/bold" : False,
               "marker/cross/text/font/italic" : False,
               "marker/cross/text/textcolor" : "darkBlue",
@@ -609,7 +668,7 @@ DEFAULTS = {
               "marker/cross/pen/style" : "SolidLine",
               "marker/cross/pen/color" : "black",
               "marker/cross/pen/width" : 1,
-              "marker/cross/linestyle" : 3,
+              "marker/cross/markerstyle" : "Cross",
               },
               
             'cross_section' :
@@ -682,7 +741,7 @@ DEFAULTS = {
               "marker/curve/symbol/facecolor" : "blue",
               "marker/curve/symbol/alpha" : .8,
               "marker/curve/symbol/size" : 8,
-              "marker/curve/text/font/size" : 11,
+              "marker/curve/text/font/size" : 8,
               "marker/curve/text/font/family" : "default",
               "marker/curve/text/font/bold" : False,
               "marker/curve/text/font/italic" : False,
@@ -692,7 +751,7 @@ DEFAULTS = {
               "marker/curve/pen/style" : "SolidLine",
               "marker/curve/pen/color" : "black",
               "marker/curve/pen/width" : 0,
-              "marker/curve/linestyle" : 0,
+              "marker/curve/markerstyle" : "NoLine",
 
               "marker/cross/symbol/marker" : 'Cross',
               "marker/cross/symbol/edgecolor" : "black",
@@ -700,7 +759,7 @@ DEFAULTS = {
               "marker/cross/symbol/alpha" : 1.,
               "marker/cross/symbol/size" : 8,
               "marker/cross/text/font/family" : "default",
-              "marker/cross/text/font/size" : 11,
+              "marker/cross/text/font/size" : 8,
               "marker/cross/text/font/bold" : False,
               "marker/cross/text/font/italic" : False,
               "marker/cross/text/textcolor" : "darkBlue",
@@ -709,7 +768,7 @@ DEFAULTS = {
               "marker/cross/pen/style" : "SolidLine",
               "marker/cross/pen/color" : "black",
               "marker/cross/pen/width" : 1,
-              "marker/cross/linestyle" : 3,
+              "marker/cross/markerstyle" : "Cross",
               },
               
             }
