@@ -37,9 +37,9 @@ Reference
 
 import weakref
 
-from PyQt4.QtGui import (QVBoxLayout, QSizePolicy, QHBoxLayout, QToolBar,
-                         QSpacerItem)
-from PyQt4.QtCore import QSize, QPoint, Qt, SIGNAL
+from guidata.qt.QtGui import (QVBoxLayout, QSizePolicy, QHBoxLayout, QToolBar,
+                              QSpacerItem)
+from guidata.qt.QtCore import QSize, QPoint, Qt, SIGNAL
 
 import numpy as np
 
@@ -758,7 +758,7 @@ class XCrossSection(CrossSectionWidget):
         event.ignore()
         
     def setup_actions(self):
-        super(XCrossSection, self).setup_actions()
+        CrossSectionWidget.setup_actions(self)
         self.peritem_ac = create_action(self, _("Per image cross-section"),
                         icon=get_icon('csperimage.png'),
                         toggled=self.cs_plot.toggle_perimage_mode,
@@ -893,7 +893,7 @@ class ObliqueCrossSectionItem(CrossSectionItem):
         rect = obj.get_bounding_rect_coords()
         if rect is not None and source.data is not None:
 #            x0, y0, x1, y1 = rect
-#            angle = obj.get_angle()
+#            angle = obj.get_tr_angle()
             sectx, secty = compute_oblique_section(source, obj)
             if secty.size == 0 or np.all(np.isnan(secty)):
                 sectx, secty = np.array([]), np.array([])
